@@ -35,11 +35,10 @@ class Config(BaseSettings):
     backend_service_name: str = "agenticlypay-backend"
     frontend_service_name: str = "agenticlypay-frontend"
 
-    # J.P. Morgan Payments API Configuration
-    jpmorgan_client_id: Optional[str] = None
-    jpmorgan_client_secret: Optional[str] = None
-    jpmorgan_token_url: str = "https://id.payments.jpmorgan.com/am/oauth2/alpha/access_token"
-    jpmorgan_api_base_url: str = "https://api.payments.jpmorgan.com"
+    # Wise API Configuration
+    wise_api_key: Optional[str] = None
+    wise_api_base_url: str = "https://api.wise.com"
+    wise_webhook_secret: Optional[str] = None
 
     # 1099 Tax Form Configuration
     payer_name: str = "AgenticlyPay"
