@@ -41,9 +41,9 @@ class TaxReporter:
         if mapping_doc.exists:
             return mapping_doc.to_dict().get("email")
         
-        # Try zelle_payouts collection
+        # Try wise_payouts collection
         payouts_query = (
-            db.collection("zelle_payouts")
+            db.collection("wise_payouts")
             .where("developer_account_id", "==", developer_account_id)
             .limit(1)
             .stream()
@@ -59,7 +59,7 @@ class TaxReporter:
         self, developer_account_id: str, year: int
     ) -> Dict[str, Any]:
         """
-        Calculate total annual earnings for a developer from Zelle payouts.
+        Calculate total annual earnings for a developer from Wise payouts.
 
         Args:
             developer_account_id: Connected account ID
@@ -72,9 +72,9 @@ class TaxReporter:
         start_date = datetime(year, 1, 1)
         end_date = datetime(year + 1, 1, 1)
         
-        # Query Zelle payouts for this account and year
+        # Query Wise payouts for this account and year
         payouts_query = (
-            db.collection("zelle_payouts")
+            db.collection("wise_payouts")
             .where("developer_account_id", "==", developer_account_id)
             .where("year", "==", year)
             .stream()
@@ -116,7 +116,7 @@ class TaxReporter:
                     "year": year,
                     "month": month,
                     "total_amount": monthly_breakdown[month]["total_amount"],
-                    "total_fees": 0,  # Fees already deducted before Zelle payout
+                    "total_fees": 0,  # Fees already deducted before Wise payout
                     "net_amount": monthly_breakdown[month]["net_amount"],
                     "transaction_count": monthly_breakdown[month]["transaction_count"],
                     "currency": "usd",
@@ -132,7 +132,7 @@ class TaxReporter:
                     "currency": "usd",
                 })
 
-        # For Zelle payouts, net_amount equals total_amount (fees already deducted)
+        # For Wise payouts, net_amount equals total_amount (fees already deducted)
         net_amount = total_amount
         total_fees = 0  # Fees were deducted before payout
 
@@ -469,7 +469,7 @@ Best regards,
         self, year: int, developer_account_ids: Optional[List[str]] = None
     ) -> Dict[str, Any]:
         """
-        Generate and send 1099 forms for all eligible developers with Zelle payouts.
+        Generate and send 1099 forms for all eligible developers with Wise payouts.
 
         Args:
             year: Tax year (e.g., 2024)
@@ -486,11 +486,11 @@ Best regards,
             "no_consent": [],
         }
 
-        # If no account IDs provided, query all developers with Zelle payouts for the year
+        # If no account IDs provided, query all developers with Wise payouts for the year
         if not developer_account_ids:
-            # Query all unique developer_account_ids from zelle_payouts for this year
+            # Query all unique developer_account_ids from wise_payouts for this year
             payouts_query = (
-                db.collection("zelle_payouts")
+                db.collection("wise_payouts")
                 .where("year", "==", year)
                 .stream()
             )
